@@ -28,7 +28,6 @@ def greet(msg: str = None) -> None:
         case _:
             print(Fore.RED + "fuck you")
 
-greet('Salam Kiara')
-greet('bye')
+
 if __name__ == '__main__':
     kavian_info()
